pub struct ExpressionInfo {
pub uniformity: Uniformity,
pub ref_count: usize,
pub ty: TypeResolution,
/* private fields */
}Expand description
Information about an expression in a function body.
Fields
uniformity: UniformityWhether this expression is uniform, and why.
If this expression’s value is not uniform, this is the handle
of the expression from which this one’s non-uniformity
originates. Otherwise, this is None.
ref_count: usizeThe number of direct references to this expression in statements and other expressions.
This is a local reference count only, it may be non-zero for expressions that are ultimately unused.
ty: TypeResolutionThe type of this expression.